@@ -14,7 +14,8 @@ class PyPI:
         self.output = Path(os.path.abspath(output) if output else repo)
         self.output.mkdir(parents=True, exist_ok=True)
         self.src = self.output / 'src'
-        (self.src / 'templates').mkdir(parents=True, exist_ok=True)
+        (self.src / package / const.TEMPLATES).mkdir(parents=True, exist_ok=True)
+        self.tests = self.src / 'tests'
         self.workflows = self.output / '.github/workflows'
         self.workflows.mkdir(parents=True, exist_ok=True)
         self.pkg = self.src / package
@@ -52,7 +53,7 @@ class PyPI:
         )
 
     def main(self):
-        (self.pkg / '__main__.py').write_text(dedent(f"""
+        (self.pkg / const.MAIN).write_text(dedent(f"""
         from {self.package} import main
 
         if __name__ == '__main__':
@@ -60,7 +61,7 @@ class PyPI:
         """).lstrip())
 
     def init(self):
-        (self.pkg / '__init__.py').write_text(dedent(f"""
+        (self.pkg / const.INIT).write_text(dedent(f"""
         __title__ = '{self.repo}'
         __author__ = '{self.user}'
         __version__ = '0.0.1'
@@ -76,6 +77,13 @@ class PyPI:
             parser.parse_args()
         """).lstrip())
 
+    def gen_tests(self):
+        self.tests.mkdir(parents=True, exist_ok=True)
+        (self.tests / const.INIT).write_text('')
+        (self.tests / const.CONFTEST).write_text(
+            (const.templates / const.CONFTEST).read_text()
+        )
+
     def generate(self):
         self.manifest()
         self.pyproject()
@@ -86,4 +94,5 @@ class PyPI:
         self.update()
         self.main()
         self.init()
+        self.gen_tests()
         return self.output
